@@ -1,5 +1,6 @@
 '''This module defines public asset data access components.'''
 import pandas as pd
+from frostaura.models.symbol_data import SymbolData
 
 class IPublicAssetDataAccess:
     '''Component to perform functions related to public assets.'''
@@ -8,3 +9,8 @@ class IPublicAssetDataAccess:
         '''Get historical price movements for a given symbol.'''
 
         raise NotImplementedError()
+
+    def get_symbol_data(self, symbol: str, ignore_cache: bool) -> SymbolData:
+        '''Get detailed information about a given symbol.'''
+
+        raise NotImplementedError()
